@@ -4,21 +4,21 @@ try:
 except ModuleNotFoundError:
     import tomli as tomllib
 
-__version__ = "0.3.0"
+__version__ = "0.5.1"
 CMDNAME = 'recbz'
 
-_cfg = tomllib.loads(resources.read_text("reCBZ", "config.toml"))
+_cfg = tomllib.loads(resources.read_text("reCBZ", "defaults.toml"))
 OVERWRITE = _cfg["archive"]["overwrite"]
-FORCE = _cfg["archive"]["force"]
+IGNORE = _cfg["archive"]["ignore"]
 LOGLEVEL = _cfg["archive"]["loglevel"]
 PARALLEL = _cfg["archive"]["parallel"]
 PROCESSES = _cfg["archive"]["processes"]
-ZIPEXT = _cfg["archive"]["zipext"]
-COMPRESSLEVEL = _cfg["archive"]["compresslevel"]
-COMPARESAMPLES = _cfg["archive"]["comparesamples"]
+OUTFORMAT = _cfg["archive"]["outformat"]
+COMPRESSZIP = _cfg["archive"]["compresszip"]
+SAMPLECOUNT = _cfg["archive"]["samplecount"]
 NOWRITE = _cfg["archive"]["nowrite"]
 BLACKLISTEDFMTS = _cfg["archive"]["blacklistedfmts"]
-FORMATNAME = _cfg["archive"]["formatname"]
+IMAGEFORMAT = _cfg["archive"]["imageformat"]
 QUALITY = _cfg["archive"]["quality"]
 RESOLUTION = _cfg["archive"]["resolution"]
 NOUPSCALE = _cfg["archive"]["noupscale"]
